# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config
NULL

#' AWS Fault Injection Simulator
#'
#' @description
#' Fault Injection Simulator is a managed service that enables you to
#' perform fault injection experiments on your Amazon Web Services
#' workloads. For more information, see the [Fault Injection Simulator User
#' Guide](https://docs.aws.amazon.com/fis/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{access_key_id}:} {AWS access key ID}
#' \item{\strong{secret_access_key}:} {AWS secret access key}
#' \item{\strong{session_token}:} {AWS temporary session token}
#' \item{\strong{profile}:} {The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}:} {Set anonymous credentials.}
#' \item{\strong{endpoint}:} {The complete URL to use for the constructed client.}
#' \item{\strong{region}:} {The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}:} {Immediately close all HTTP connections.}
#' \item{\strong{timeout}:} {The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}:} {Set this to `true` to force the request to use path-style addressing, i.e., `http://s3.amazonaws.com/BUCKET/KEY`.}
#' }
#'
#' @section Service syntax:
#' ```
#' svc <- fis(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical"
#'   )
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- fis()
#' svc$create_experiment_template(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=fis_create_experiment_template]{create_experiment_template} \tab Creates an experiment template\cr
#'  \link[=fis_delete_experiment_template]{delete_experiment_template} \tab Deletes the specified experiment template\cr
#'  \link[=fis_get_action]{get_action} \tab Gets information about the specified FIS action\cr
#'  \link[=fis_get_experiment]{get_experiment} \tab Gets information about the specified experiment\cr
#'  \link[=fis_get_experiment_template]{get_experiment_template} \tab Gets information about the specified experiment template\cr
#'  \link[=fis_get_target_resource_type]{get_target_resource_type} \tab Gets information about the specified resource type\cr
#'  \link[=fis_list_actions]{list_actions} \tab Lists the available FIS actions\cr
#'  \link[=fis_list_experiments]{list_experiments} \tab Lists your experiments\cr
#'  \link[=fis_list_experiment_templates]{list_experiment_templates} \tab Lists your experiment templates\cr
#'  \link[=fis_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[=fis_list_target_resource_types]{list_target_resource_types} \tab Lists the target resource types\cr
#'  \link[=fis_start_experiment]{start_experiment} \tab Starts running an experiment from the specified experiment template\cr
#'  \link[=fis_stop_experiment]{stop_experiment} \tab Stops the specified experiment\cr
#'  \link[=fis_tag_resource]{tag_resource} \tab Applies the specified tags to the specified resource\cr
#'  \link[=fis_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[=fis_update_experiment_template]{update_experiment_template} \tab Updates the specified experiment template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname fis
#' @export
fis <- function(config = list()) {
  svc <- .fis$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.fis <- list()

.fis$operations <- list()

.fis$metadata <- list(
  service_name = "fis",
  endpoints = list("*" = list(endpoint = "fis.{region}.amazonaws.com", global = FALSE), "cn-*" = list(endpoint = "fis.{region}.amazonaws.com.cn", global = FALSE), "us-iso-*" = list(endpoint = "fis.{region}.c2s.ic.gov", global = FALSE), "us-isob-*" = list(endpoint = "fis.{region}.sc2s.sgov.gov", global = FALSE)),
  service_id = "fis",
  api_version = "2020-12-01",
  signing_name = "fis",
  json_version = "1.1",
  target_prefix = ""
)

.fis$service <- function(config = list()) {
  handlers <- new_handlers("restjson", "v4")
  new_service(.fis$metadata, handlers, config)
}
